<img src="https://bytebucket.org/artegorov/svist4get/raw/a46b54c2a59bf278e6d1cf1fb3e728de7971eb3f/docs/logo_128.png" alt="drawing" width="100"/>

Svist4get is a simple bioinformatics tool for visualization of genomic signal tracks in user-defined genomic windows, either arbitrary selected by genomic coordinates or anchored to particular transcripts or genes.



The detailed documentation is available at [Home Page](https://bitbucket.org/artegorov/svist4get/)
